@@ -1,6 +1,6 @@
 import math
-
 import warnings
+
 import numpy as np
 from plum import Union
 
@@ -161,17 +161,27 @@ def isscalar(a):  # pragma: no cover
 
 
 @dispatch
-@abstract()
-def expand_dims(a: Numeric, axis: Int = 0):  # pragma: no cover
+def expand_dims(a: Numeric, axis: Int = 0, times: Int = 1):
     """Insert an empty axis.
 
     Args:
         a (tensor): Tensor.
         axis (int, optional): Index of new axis. Defaults to `0`.
+        times (int, optional): Number of times to perform the operation. Defaults to
+            `1`.
 
     Returns:
         tensor: `a` with the new axis.
     """
+    for _ in range(times):
+        a = _expand_dims(a, axis=axis)
+    return a
+
+
+@dispatch
+@abstract()
+def _expand_dims(a, axis: Int = 0):  # pragma: no cover
+    pass
 
 
 @dispatch
@@ -310,14 +320,14 @@ def diag_construct(a: Numeric):  # pragma: no cover
 
 
 @dispatch
-def flatten(a: Numeric):  # pragma: no cover
-    """Flatten a tensor.
+def flatten(a):
+    """Flatten an object that can be reshaped.
 
     Args:
-        a (tensor): Tensor.
+        a (object): Object.
 
     Returns:
-        tensor: Flattened tensor.
+        tensor: Flattened object.
     """
     return reshape(a, -1)
 
@@ -362,7 +372,7 @@ def vec_to_tril(a: Numeric, offset: Int = 0):
 
 
 @dispatch
-def tril_to_vec(a: Numeric, offset: Int = 0):
+def tril_to_vec(a, offset: Int = 0):
     """Construct a vector from a lower triangular matrix.
 
     Args:
@@ -399,17 +409,26 @@ def stack(*elements, **kw_args):  # pragma: no cover
 
 
 @dispatch
-@abstract()
-def unstack(a: Numeric, axis: Int = 0):  # pragma: no cover
+def unstack(a: Numeric, axis: Int = 0, squeeze: bool = True):
     """Unstack tensors along an axis.
 
     Args:
         a (list): List of tensors.
         axis (int, optional): Index along which to unstack. Defaults to `0`.
+        squeeze (bool, optional): Squeeze the unstacked dimension. Defaults to `True`.
 
     Returns:
         list[tensor]: List of tensors.
     """
+    elements = _unstack(a, axis=axis)
+    if not squeeze:
+        elements = [B.expand_dims(x, axis=axis) for x in elements]
+    return elements
+
+
+@dispatch.abstract
+def _unstack():  # pragma: no cover
+    pass
 
 
 @dispatch
@@ -451,7 +470,7 @@ def concat2d(*rows: Union[list]):
     Returns:
         tensor: Assembled matrix.
     """
-    return concat(*[concat(*row, axis=1) for row in rows], axis=0)
+    return concat(*[concat(*row, axis=-1) for row in rows], axis=-2)
 
 
 @dispatch
