@@ -14,7 +14,7 @@ def length(a: Numeric):
 
 
 @dispatch
-def expand_dims(a: Numeric, axis: Int = 0):
+def _expand_dims(a: Numeric, axis: Int = 0):
     return tf.expand_dims(a, axis=axis)
 
 
@@ -54,7 +54,7 @@ def stack(*elements: Numeric, axis: Int = 0):
 
 
 @dispatch
-def unstack(a: Numeric, axis: Int = 0):
+def _unstack(a: Numeric, axis: Int = 0):
     return tf.unstack(a, axis=axis)
 
 
